==> icradius-0.13-pre1.tar.gz: icradius-0.13-pre1/src/version.c <==
/*
 *
 *	RADIUS
 *	Remote Authentication Dial In User Service
 *
 *
 *	Livingston Enterprises, Inc.
 *	6920 Koll Center Parkway
 *	Pleasanton, CA   94566
 *
 *	Copyright 1992 Livingston Enterprises, Inc.
 *
 *	Permission to use, copy, modify, and distribute this software for any
 *	purpose and without fee is hereby granted, provided that this
 *	copyright and permission notice appear on all copies and supporting
 *	documentation, the name of Livingston Enterprises, Inc. not be used
 *	in advertising or publicity pertaining to distribution of the
 *	program without specific prior permission, and notice be given
 *	in supporting documentation that copying and distribution is by
 *	permission of Livingston Enterprises, Inc.   
 *
 *	Livingston Enterprises, Inc. makes no representations about
 *	the suitability of this software for any purpose.  It is
 *	provided "as is" without express or implied warranty.
 *
 */

char version_sccsid[] =
"@(#)version.c	1.3 Copyright 1992 Livingston Enterprises Inc";

#include        <sys/types.h>
#include	<stdio.h>
#include	"radiusd.h"

/*  If you make any changes to this software please update this
 *  version number; contact support@livingston.com if you
 *  would like a range of versions allocated for your use.
 */

#define		VERSION		"ICRADIUS 0.13-pre1 2000-03-07"

/*
 *	Display the revision number for this program
 */
void version(void)
{

	fprintf(stderr, "%s: RADIUS version %s\n", progname, VERSION);
	fprintf(stderr, "Compilation flags: ");

	/* here are all the conditional feature flags */
#if defined(NOSHADOW)
	fprintf(stderr," NOSHADOW");
#endif
#if defined(OSFC2)
	fprintf(stderr," OSFC2");
#endif
#if defined(NT_DOMAIN_HACK)
	fprintf(stderr," NT_DOMAIN_HACK");
#endif
#if defined(SPECIALIX_JETSTREAM_HACK)
	fprintf(stderr," SPECIALIX_JETSTREAM_HACK");
#endif
#if defined(CISCO_ACCOUNTING_HACK)
	fprintf(stderr, " CISCO_ACCOUNTING_HACK");
#endif
#if defined(NOCASE)
	fprintf(stderr," NOCASE");
#endif
#if defined(ATTRIB_NMC)
	fprintf(stderr, " ATTRIB_NMC");
#endif
#if defined(COMPAT_1543)
	fprintf(stderr, " COMPAT_1543");
#endif

	/* here are all the system definitions compilation uses */
#if defined(__alpha)
	fprintf(stderr," __alpha");
#endif
#if defined(__osf__)
	fprintf(stderr," __osf__");
#endif
#if defined(aix)
	fprintf(stderr," aix");
#endif
#if defined(bsdi)
	fprintf(stderr," bsdi");
#endif
#if defined(sun)
	fprintf(stderr," sun");
#endif
#if defined(sys5)
	fprintf(stderr," sys5");
#endif
#if defined(unixware)
	fprintf(stderr," unixware");
#endif
#if defined(__linux__)
	fprintf(stderr," linux");
#endif
#if defined(M_UNIX)
	fprintf(stderr," M_UNIX");
#endif
	fprintf(stderr,"\n");
	exit(0);
}

==> icradius-0.14-pre1.tar.gz: icradius-0.14-pre1/src/version.c <==
/*
 *
 *	RADIUS
 *	Remote Authentication Dial In User Service
 *
 *
 *	Livingston Enterprises, Inc.
 *	6920 Koll Center Parkway
 *	Pleasanton, CA   94566
 *
 *	Copyright 1992 Livingston Enterprises, Inc.
 *
 *	Permission to use, copy, modify, and distribute this software for any
 *	purpose and without fee is hereby granted, provided that this
 *	copyright and permission notice appear on all copies and supporting
 *	documentation, the name of Livingston Enterprises, Inc. not be used
 *	in advertising or publicity pertaining to distribution of the
 *	program without specific prior permission, and notice be given
 *	in supporting documentation that copying and distribution is by
 *	permission of Livingston Enterprises, Inc.   
 *
 *	Livingston Enterprises, Inc. makes no representations about
 *	the suitability of this software for any purpose.  It is
 *	provided "as is" without express or implied warranty.
 *
 */

char version_sccsid[] =
"@(#)version.c	1.3 Copyright 1992 Livingston Enterprises Inc";

#include        <sys/types.h>
#include	<stdio.h>
#include	"radiusd.h"

/*  If you make any changes to this software please update this
 *  version number; contact support@livingston.com if you
 *  would like a range of versions allocated for your use.
 */

#define		VERSION		"ICRADIUS 0.14-pre1 built " __DATE__

/*
 *	Display the revision number for this program
 */
void version(void)
{

	fprintf(stderr, "%s: RADIUS version %s\n", progname, VERSION);
	fprintf(stderr, "Compilation flags: ");

	/* here are all the conditional feature flags */
#if defined(NOSHADOW)
	fprintf(stderr," NOSHADOW");
#endif
#if defined(OSFC2)
	fprintf(stderr," OSFC2");
#endif
#if defined(NT_DOMAIN_HACK)
	fprintf(stderr," NT_DOMAIN_HACK");
#endif
#if defined(SPECIALIX_JETSTREAM_HACK)
	fprintf(stderr," SPECIALIX_JETSTREAM_HACK");
#endif
#if defined(CISCO_ACCOUNTING_HACK)
	fprintf(stderr, " CISCO_ACCOUNTING_HACK");
#endif
#if defined(NOCASE)
	fprintf(stderr," NOCASE");
#endif
#if defined(ATTRIB_NMC)
	fprintf(stderr, " ATTRIB_NMC");
#endif
#if defined(COMPAT_1543)
	fprintf(stderr, " COMPAT_1543");
#endif

	/* here are all the system definitions compilation uses */
#if defined(__alpha)
	fprintf(stderr," __alpha");
#endif
#if defined(__osf__)
	fprintf(stderr," __osf__");
#endif
#if defined(aix)
	fprintf(stderr," aix");
#endif
#if defined(bsdi)
	fprintf(stderr," bsdi");
#endif
#if defined(sun)
	fprintf(stderr," sun");
#endif
#if defined(sys5)
	fprintf(stderr," sys5");
#endif
#if defined(unixware)
	fprintf(stderr," unixware");
#endif
#if defined(__linux__)
	fprintf(stderr," linux");
#endif
#if defined(M_UNIX)
	fprintf(stderr," M_UNIX");
#endif
	fprintf(stderr,"\n");
	exit(0);
}
